# iTaxoTools common resources

[![PyPI - Version](https://img.shields.io/pypi/v/itaxotools-common)](
    https://pypi.org/project/itaxotools-common)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/itaxotools-common)](
    https://pypi.org/project/itaxotools-common)
[![PyPI - License](https://img.shields.io/pypi/l/itaxotools-common)](
    https://pypi.org/project/itaxotools-common)
[![GitHub - Tests](https://img.shields.io/github/actions/workflow/status/iTaxoTools/itt-common/test.yml?label=tests)](
    https://github.com/iTaxoTools/itt-common/actions/workflows/test.yml)

This package contains common modules and resources for use by other iTaxoTools projects:

- Logos and icon resources, including import machinery
- Custom binding interface for PySide6 properties
- Multi-processing utilities for PySide6
- PyInstaller hook directory definition
